@@ -2,7 +2,7 @@ import logging
 from typing import Optional
 
 from the_spymaster_util.http_client import BaseHttpClient
-from the_spymaster_util.logging import wrap
+from the_spymaster_util.logger import wrap
 from urllib3 import Retry
 
 from .structs import (
